/*
 * argv.h
 *
 * Copyright (c) 2001 Dug Song <dugsong@monkey.org>
 *
 * $Id$
 */

#pragma once

int argv_create(char *p, int argc, char *argv[]);
char *argv_copy(char *argv[]);
